#!/bin/bash
#
# 2010.06.09, Rev.00-00-01 IPMI over LAN
# 2012.10.12, Rev.00-00-02 supported vMA(ESXi5)
# 2014.09.18, Rev.00-00-03
# 2015.01.28, Rev.00-00-04 ipmiRawCmd command pass change.
# 2016.04.12, Rev.00-00-05 support vRHEL
# SelManager installer for Linux (VMWare)

SELMANAGER_PROG="SelManager_01-03-02.tgz"
VMWSELMANAGER_PROG="SelManager_vmwtool_01-00-03.tgz"
VMWSELMANAGER_PROG_VMA="SelManager_vmwtool_vma_01-00-00.tgz"

SELMANAGER_INSTALL_DIR="/opt/hitachi/SelManager"
SELMANAGER_CONFIG_FILE="${SELMANAGER_INSTALL_DIR}/SelManager.conf"
VMWSELMANAGER_CONFIG_FILE="${SELMANAGER_INSTALL_DIR}/vmwSelManager.conf"
export W_PATH=`echo "${0}" | sed 's/\/[^/]*$//'`

func_service_stop() {
#	if [ $VMA_RUN ]; then
	if [ $VMA_RUN -eq 1 ]; then
		if [ -f /etc/init.d/SelManager ]; then
			SELMANAGER_PID=`pidof SelManager`
			if [ -n "${SELMANAGER_PID}" -a -d /proc/$SELMANAGER_PID ]; then
				/etc/init.d/SelManager stop
			fi
		fi
	else
		if [ -f /etc/rc.d/init.d/SelManager ]; then
			SELMANAGER_PID=`pidof SelManager`
			if [ -n "${SELMANAGER_PID}" -a -d /proc/$SELMANAGER_PID ]; then
				/etc/rc.d/init.d/SelManager stop
			fi
		fi
	fi
}

# Run user check
if [ `id -u` != "0" ]; then
	echo "Please execute it by \"root\" user."
	exit 1
fi
# vMA ?
VMA_RUN=0
if [ -f /etc/vma-release ]; then
	VMA_RUN=1
fi

#---------------------------------------------------------------
# Get the Platform type and more.
#---------------------------------------------------------------
RHEL_INFO=/etc/redhat-release
VMA_INFO=/etc/vma-release

#IS_GUESTOS=100
IS_GUESTOS=1
which virt-what > /dev/null 2>&1
if [ $? -eq 0 ]; then
	IS_GUESTOS=1
	VMMACHINE=`virt-what`
	if [ ${#VMMACHINE} -ne 0 ]; then
#		echo "`date` virt-what: ${VMMACHINE}" >> /opt/hitachi/SelManager/install.log 2>&1
		if [ $VMMACHINE = "vmware" ]; then
			IS_GUESTOS=0
		fi
	fi
fi

# Installation check of ipmitool
#if [ ! $VMA_RUN ]; then
if [ $VMA_RUN -ne 1 -a $IS_GUESTOS -ne 0 ]; then
	if [ ! -f /usr/bin/ipmitool ]; then
		echo "There are not OpenIPMI and an OpenIPMI-tools package."
		exit 1
	fi
fi

# extract SEL Manager
if [ -d ${SELMANAGER_INSTALL_DIR} ]; then
	func_service_stop
else
	mkdir -p ${SELMANAGER_INSTALL_DIR}
fi
cat ${W_PATH}/${SELMANAGER_PROG} | (cd ${SELMANAGER_INSTALL_DIR}; tar zxf - > /dev/null)
#if [ $VMA_RUN ]; then
if [ $VMA_RUN -eq 1 ]; then
	cat ${W_PATH}/${VMWSELMANAGER_PROG_VMA} | (cd ${SELMANAGER_INSTALL_DIR}; tar zxf - > /dev/null)
	cp ${W_PATH}/UninstSelMan.sh ${SELMANAGER_INSTALL_DIR}
elif [ $IS_GUESTOS -eq 0 ]; then
	cp ${W_PATH}/UninstSelMan.sh ${SELMANAGER_INSTALL_DIR}
else
	cat ${W_PATH}/${VMWSELMANAGER_PROG} | (cd ${SELMANAGER_INSTALL_DIR}; tar zxf - > /dev/null)
fi

# load SEL Manager
#if [ $VMA_RUN ]; then
if [ $VMA_RUN -eq 1 ]; then
	cp ${SELMANAGER_INSTALL_DIR}/rc.d/SelManager_vma /etc/init.d/SelManager
else
	cp ${SELMANAGER_INSTALL_DIR}/rc.d/SelManager /etc/rc.d/init.d
fi
chkconfig --add SelManager > /opt/hitachi/SelManager/install.log 2>&1
#echo "`date` chkconfig: `chkconfig --add SelManager`" >> /opt/hitachi/SelManager/install.log 2>&1

#if [ ! $VMA_RUN ]; then
if [ $VMA_RUN -ne 1 -a $IS_GUESTOS -ne 0 ]; then
	echo ""
	${SELMANAGER_INSTALL_DIR}/VmwSelManConf.sh "SETUP"
fi

#if [ $VMA_RUN ]; then
if [ $VMA_RUN -eq 1 -o $IS_GUESTOS -eq 0 ]; then
	if [ -f /opt/hitachi/snv/provider/BMC_IPMI/ipmiRawCmd ]; then
		cat ${SELMANAGER_CONFIG_FILE} | sed -e "s/\/usr\/bin\/ipmitool/\/opt\/hitachi\/snv\/provider\/BMC_IPMI\/ipmiRawCmd/" > ${SELMANAGER_CONFIG_FILE}_tmp
	elif [ -f /opt/hitachi/tools/miacat/ipmiRawCmd ]; then
		cat ${SELMANAGER_CONFIG_FILE} | sed -e "s/\/usr\/bin\/ipmitool/\/opt\/hitachi\/tools\/miacat\/ipmiRawCmd/" > ${SELMANAGER_CONFIG_FILE}_tmp
	else
		echo "Installation failure (ipmiRawCmd not found)."
		exit 1
	fi
else
	# ToolPath		/usr/bin/ipmitool
	cat ${SELMANAGER_CONFIG_FILE} | sed -e "s/\/usr\/bin\/ipmitool/\/opt\/hitachi\/SelManager\/vmw_ipmitool.sh/" > ${SELMANAGER_CONFIG_FILE}_tmp
fi
mv -f ${SELMANAGER_CONFIG_FILE}_tmp ${SELMANAGER_CONFIG_FILE}

sleep 1
service SelManager start

sleep 15
SELMANAGER_PID=`pidof SelManager`
if [ -n "${SELMANAGER_PID}" -a -d /proc/$SELMANAGER_PID ]; then
	echo "Installed successfully."
else
	echo "Installation failure."
	exit 1
fi
exit 0
